@@ -3,12 +3,12 @@ import gc
 from dgl.data.utils import Subset
 import pandas as pd
 from dgl.data.chem import csv_dataset, smiles_to_bigraph, MoleculeCSVDataset
-from gnn_utils import AttentiveFPBondFeaturizer, AttentiveFPAtomFeaturizer, collate_molgraphs, \
+from bokeys.gnn_utils import AttentiveFPBondFeaturizer, AttentiveFPAtomFeaturizer, collate_molgraphs, \
     EarlyStopping, set_random_seed, Meter
 from torch.nn import BCEWithLogitsLoss, MSELoss
 from torch.utils.data import DataLoader
 import torch
-from splitdater import split_dataset
+from bokeys.splitdater import split_dataset
 from dgl.model_zoo.chem import MPNNModel, GCNClassifier, GATClassifier, AttentiveFP
 import numpy as np
 from sklearn.model_selection import train_test_split
